==> camel-k-model-v1alpha1-5.3.0-sources.jar: io/fabric8/camelk/v1alpha1/KameletListFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KameletListFluent<A extends KameletListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,Kamelet item);
    public A setToItems(int index,Kamelet item);
    public A addToItems(Kamelet... items);
    public A addAllToItems(Collection<Kamelet> items);
    public A removeFromItems(Kamelet... items);
    public A removeAllFromItems(Collection<Kamelet> items);
    public A removeMatchingFromItems(Predicate<KameletBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Kamelet> getItems();
    public List<Kamelet> buildItems();
    public Kamelet buildItem(int index);
    public Kamelet buildFirstItem();
    public Kamelet buildLastItem();
    public Kamelet buildMatchingItem(Predicate<KameletBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<KameletBuilder> predicate);
    public A withItems(List<Kamelet> items);
    public A withItems(Kamelet... items);
    public Boolean hasItems();
    public KameletListFluent.ItemsNested<A> addNewItem();
    public KameletListFluent.ItemsNested<A> addNewItemLike(Kamelet item);
    public KameletListFluent.ItemsNested<A> setNewItemLike(int index,Kamelet item);
    public KameletListFluent.ItemsNested<A> editItem(int index);
    public KameletListFluent.ItemsNested<A> editFirstItem();
    public KameletListFluent.ItemsNested<A> editLastItem();
    public KameletListFluent.ItemsNested<A> editMatchingItem(Predicate<KameletBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KameletFluent<KameletListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> camel-k-model-v1alpha1-5.3.2-sources.jar: io/fabric8/camelk/v1alpha1/KameletListFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KameletListFluent<A extends KameletListFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,Kamelet item);
    public A setToItems(int index,Kamelet item);
    public A addToItems(Kamelet... items);
    public A addAllToItems(Collection<Kamelet> items);
    public A removeFromItems(Kamelet... items);
    public A removeAllFromItems(Collection<Kamelet> items);
    public A removeMatchingFromItems(Predicate<KameletBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Kamelet> getItems();
    public List<Kamelet> buildItems();
    public Kamelet buildItem(int index);
    public Kamelet buildFirstItem();
    public Kamelet buildLastItem();
    public Kamelet buildMatchingItem(Predicate<KameletBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<KameletBuilder> predicate);
    public A withItems(List<Kamelet> items);
    public A withItems(Kamelet... items);
    public Boolean hasItems();
    public io.fabric8.camelk.v1alpha1.KameletListFluent.ItemsNested<A> addNewItem();
    public io.fabric8.camelk.v1alpha1.KameletListFluent.ItemsNested<A> addNewItemLike(Kamelet item);
    public io.fabric8.camelk.v1alpha1.KameletListFluent.ItemsNested<A> setNewItemLike(int index,Kamelet item);
    public io.fabric8.camelk.v1alpha1.KameletListFluent.ItemsNested<A> editItem(int index);
    public io.fabric8.camelk.v1alpha1.KameletListFluent.ItemsNested<A> editFirstItem();
    public io.fabric8.camelk.v1alpha1.KameletListFluent.ItemsNested<A> editLastItem();
    public io.fabric8.camelk.v1alpha1.KameletListFluent.ItemsNested<A> editMatchingItem(Predicate<KameletBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KameletFluent<io.fabric8.camelk.v1alpha1.KameletListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
